@@ -3,11 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0702';
+our $VERSION = '0.0703';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
 use List::Util qw(any);
+use MIDI::Util qw(dura_size ticks);
 use strictures 2;
 use namespace::clean;
 
@@ -170,6 +171,55 @@ sub rupaktaal {
     $self->strike('na', $dura);
 }
 
+sub ektaal {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    my $ticks = ticks($self->score);
+    my $dura4 = 'd' . ($ticks * dura_size($dura) / 4);
+    $self->strike('dhin', $dura);
+    $self->strike('dhin', $dura);
+    $self->strike('dha', $dura);
+    $self->tirakita($dura4);
+    $self->strike('ti', $dura);
+    $self->strike('na', $dura);
+    $self->strike('ke', $dura);
+    $self->strike('ta', $dura);
+    $self->strike('dha', $dura);
+    $self->tirakita($dura4);
+    $self->strike('dhin', $dura);
+    $self->strike('na', $dura);
+}
+
+sub arachartaal {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    my $ticks = ticks($self->score);
+    my $dura4 = 'd' . ($ticks * dura_size($dura) / 4);
+    $self->strike('dhin', $dura);
+    $self->tirakita($dura4);
+    $self->strike('dhit', $dura);
+    $self->strike('na', $dura);
+    $self->strike('ti', $dura);
+    $self->strike('na', $dura);
+    $self->strike('ke', $dura);
+    $self->strike('ta', $dura);
+    $self->tirakita($dura4);
+    $self->strike('dhit', $dura);
+    $self->strike('na', $dura);
+    $self->strike('dhit', $dura);
+    $self->strike('dhit', $dura);
+    $self->strike('na', $dura);
+}
+
+sub tirakita {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    $self->strike('ti', $dura);
+    $self->strike('na', $dura);
+    $self->strike('ke', $dura);
+    $self->strike('ta', $dura);
+}
+
 1;
 
 __END__
@@ -184,7 +234,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0702
+version 0.0703
 
 =head1 SYNOPSIS
 
@@ -209,11 +259,16 @@ version 0.0702
 
   $t->rest($t->quarter);
 
-  $t->teentaal($t->eighth)  for 1 .. $t->bars;
+  $t->tirakita($t->sixteenth) for 1 .. 2;
+
+  $t->teentaal;
   $t->keherawa($t->eighth)  for 1 .. $t->bars;
   $t->jhaptaal($t->eighth)  for 1 .. $t->bars;
   $t->dadra($t->eighth)     for 1 .. $t->bars;
   $t->rupaktaal($t->eighth) for 1 .. $t->bars;
+  $t->rupaktaal($t->eighth) for 1 .. $t->bars;
+  $t->ektaal;
+  $t->arachartaal;
 
   $t->play_with_timidity;
   # OR:
@@ -380,6 +435,18 @@ Traditional "groove patterns":
 
 7 beats
 
+=item ektaal([$duration])
+
+12 beats
+
+=item arachartaal([$duration])
+
+14 beats
+
+=item tirakita([$duration])
+
+4 beats
+
 =back
 
 =head1 SEE ALSO
